==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.md <==
# AmazonRedshiftDenseStorageNode


```text
aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')
```



| Illustration | AmazonRedshiftDenseStorageNode | AmazonRedshiftDenseStorageNodeCard | AmazonRedshiftDenseStorageNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.png) | ![illustration for AmazonRedshiftDenseStorageNode](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.Local.png) | ![illustration for AmazonRedshiftDenseStorageNodeCard](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNodeCard.Local.png) | ![illustration for AmazonRedshiftDenseStorageNodeGroup](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNodeGroup.Local.png) |




## AmazonRedshiftDenseStorageNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNode
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNode('AmazonRedshiftDenseStorageNode', 'Amazon Redshift Dense Storage Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNode
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNode('AmazonRedshiftDenseStorageNode', 'Amazon Redshift Dense Storage Node', 'an optional tech label')
@enduml
```

## AmazonRedshiftDenseStorageNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeCard('AmazonRedshiftDenseStorageNodeCard', 'Amazon Redshift Dense Storage Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeCard('AmazonRedshiftDenseStorageNodeCard', 'Amazon Redshift Dense Storage Node Card', 'an optional description')
@enduml
```

## AmazonRedshiftDenseStorageNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeGroup('AmazonRedshiftDenseStorageNodeGroup', 'Amazon Redshift Dense Storage Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeGroup('AmazonRedshiftDenseStorageNodeGroup', 'Amazon Redshift Dense Storage Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.md <==
# AmazonRedshiftDenseStorageNode


```text
aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode
```

```text
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')
```



| Illustration | AmazonRedshiftDenseStorageNode | AmazonRedshiftDenseStorageNodeCard | AmazonRedshiftDenseStorageNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.png) | ![illustration for AmazonRedshiftDenseStorageNode](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode.Local.png) | ![illustration for AmazonRedshiftDenseStorageNodeCard](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNodeCard.Local.png) | ![illustration for AmazonRedshiftDenseStorageNodeGroup](../../../aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNodeGroup.Local.png) |




## AmazonRedshiftDenseStorageNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNode
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNode('AmazonRedshiftDenseStorageNode', 'Amazon Redshift Dense Storage Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNode
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNode('AmazonRedshiftDenseStorageNode', 'Amazon Redshift Dense Storage Node', 'an optional tech label')
@enduml
```

## AmazonRedshiftDenseStorageNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeCard('AmazonRedshiftDenseStorageNodeCard', 'Amazon Redshift Dense Storage Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeCard
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeCard('AmazonRedshiftDenseStorageNodeCard', 'Amazon Redshift Dense Storage Node Card', 'an optional description')
@enduml
```

## AmazonRedshiftDenseStorageNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeGroup('AmazonRedshiftDenseStorageNodeGroup', 'Amazon Redshift Dense Storage Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseStorageNodeGroup
include('aws-20210730/Resource/Analytics/AmazonRedshiftDenseStorageNode')

' renders the element
AmazonRedshiftDenseStorageNodeGroup('AmazonRedshiftDenseStorageNodeGroup', 'Amazon Redshift Dense Storage Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
